Assignment

Struct Assignment 

pub struct Assignment<V> {
    pub assignment: Vec<V>,
}
Data structure to store mapping from VarIdx to VarType.

Fields

assignment: Vec<V>

Implementations

Source

impl<V> Assignment<V>
where V: VarType,

pub fn with_size(size: usize) -> Self

Initialize a new Assignment with specific size where all entries are set to the default value of VarType.

pub fn resize(&mut self, new_len: usize)

Resizes the Assignment to the given new_len.

If new_len is smaller than the current len of Assignment, the Assignment is truncated to new_len. If new_len is larger than the current len of Assignment, then Assignment is increased up to new_len and filled with the default values for VarType, but the entries up to the current length are left unchanged.

pub fn set_value(&mut self, idx: VarIdx, value: V::Value)

Set variable at index idx to value.

pub fn get_value(&self, idx: VarIdx) -> V::Value

Get the value of the variable at index idx.

pub fn set_lit_value(&mut self, lit: Lit, value: V::Value)

Set a value by using a Lit. Hence, if Lit is negated, then the value assigned to its variable is negated.

pub unsafe fn set_lit_value_unchecked(&mut self, lit: Lit, value: V::Value)

Set a value by literal. Hence, if the literal is negated, then value assigned to its variable is negated.

Safety

The caller must ensure that the Assignment has a large enough size, so that the variable index of lit is at most that size.

Using a lit with variable index of at least the size of Assignment is undefined behaviour.

pub fn get_lit_value(&self, lit: Lit) -> V::Value

Get the value of a Lit. Hence, if Lit is negated, then value assigned to its variable is negated.

pub unsafe fn get_lit_value_unchecked(&self, lit: Lit) -> V::Value

Same as get_lit_value but without bounds check.

Safety

The caller must ensure that the Assignment has a large enough size, so that the variable index of lit is at most that size.

Using a lit with variable index of at least the size of Assignment is undefined behaviour.

pub fn reset(&mut self)

Reset the Assignment to its default values.

pub fn len(&self) -> usize

Returns the number of variables in the Assignment no matter their value.

pub fn is_empty(&self) -> bool

Returns true if the assignment is empty, i.e., it contains no variables, neither unassigned nor assigned.

Source

impl Assignment<BooleanVar>

pub fn from(literals: &Vec<Lit>) -> Option<Self>

Create an Assignment from a Vec<Lit>.

Returns Some(assignment) if the literals are consistent, i.e., Vec<Lit> does not contain a literal and its negation. If literals is not consistent, then None is returned.

pub fn is_unassigned(&self, var: VarIdx) -> bool

Test if the variable is unassigned.

Returns true if the variable matches BoolValue::Unassigned.

pub fn is_assigned(&self, var: VarIdx) -> bool

Test if the variable is assigned to some value.

Returns true if the variable matches BoolValue::Assigned(_).